@@ -78,6 +78,7 @@ module Kbgen (
     Resolved(..),
     ArgIndex(..),
     ParamIndex(..),
+    MethodName(..),
     ResolvedType(..),
     CallResolved(..),
     ResolvedSuper(..),
@@ -295,7 +296,7 @@ data ParamName = ParamName
 -- This is how the fact will look inside the Prolog file
 --
 -- @
--- kb_call_method_of_super( Method, ResolvedSuper ).
+-- kb_call_method_of_super( Call, Method, ResolvedSuper ).
 -- @
 --
 -- __When should I use this fact__ ( motivation: [CVE-2024-53995](https://nvd.nist.gov/vuln/detail/CVE-2024-53995) )
@@ -310,7 +311,6 @@ data ParamName = ParamName
 --     def post(self, ...):
 --         n = self.get_query_argument("next", ...)
 --         self.redirect(n or ...)
---
 -- @
 --
 -- See complete source example [here](https://github.com/SickChill/sickchill/blob/846adafdfab579281353ea08a27bbb813f9a9872/sickchill/views/authentication.py#L10),
@@ -321,9 +321,9 @@ data ParamName = ParamName
 --
 -- @
 -- user_controlled_query_argument( Call ) :-
---     kb_call_method_of_super( Call, 'get_query_argument', 'tornado.web.RequestHandler' ),
+--     kb_call_method_of_super( Call, \'get_query_argument\', \'tornado.web.RequestHandler\' ),
 --     kb_arg_i_for_call( QueryParamName, 0, Call),
---     kb_const_string( QueryParamName ).
+--     kb_const_string( QueryParamName, _ ).
 --
 -- @
 --
